Gothenburg Blizzard Gothenburg, Sweden January 12th 2003 12 players Sten Düring Deck Name: CE Firepower Description: Camarilla Edition version of an older tournament winner based on Toreadors with Obfuscate. Disguise out big guns, block and torporize while tasting back blood for later bloat. The deck is very expensive to play so Parity Shift with a couple of token stealth-cards is there to help you get back in business. There's just enough rush to keep players wary of you, but count on having to spend at least three turns doing nothing while bloating. Crypt (12 cards, min=24, max=40, avg=8.25) ------------------------------------------ 2x François Villon 10 AUS CEL PRE chi obf pot prince Toreador:2 1x Helena 10 AUS CEL DOM obf pre tha Toreador:3 1x Jaroslav Pascek 10 CEL POT PRE for obf justicar Brujah:3 1x Casino Reeds 9 ANI OBF POT cel dem prince Nosferatu:3 1x Joaquin Murietta 9 AUS CEL obf pre qui Toreador:3 1x Klaus van der Veken 9 CEL PRE aus obf tha prince Toreador:2 1x Fatima al-Faqadi 8 CEL OBF QUI aus for Assamite:2 1x Suzanne Kadim 7 CEL PRE aus dom obf Toreador:3 1x Antoinette, She Who Watches 6 AUS PRE cel obf primogen Toreador:3 1x Ruth McGinley 6 DEM aus cel obf primogen Malkavian:3 1x Calebros, The Martyr 5 ANI obf pot prince Nosferatu:2 Library (90 cards) Master (23) 1x Art Museum 7x Blood Doll 3x Celerity 1x Club Zombie 1x Giant's Blood 1x Guardian Angel 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 4x Parthenon, The 1x Powerbase: Montreal 1x Rack, The 1x Society Hunting Ground Action (3) 3x Nose of the Hound Equipment (12) 5x Assault Rifle 1x Flak Jacket 2x IR Goggles 1x Ivory Bow 1x Palatial Estate 1x Pier 13, Port of Baltimore 1x Sport Bike Political Action (5) 3x Parity Shift 1x Praxis Seizure: Monaco 1x Toreador Justicar Retainer (1) 1x Mr. Winthrop Action Modifier (5) 2x Forgotten Labyrinth 3x Mask of a Thousand Faces Reaction (16) 5x Forced Awakening 7x Second Tradition: Domain 4x Telepathic Misdirection Combat (25) 6x Disguised Weapon 8x Pursuit 5x Sideslip 6x Taste of Vitae